﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;


namespace ScriptedSeries
{
	public partial class MainForm : Form
	{
		const string DefaultFormula = "Sin(x / 10) * Cos(x) * 20";

		public MainForm()
		{
			InitializeComponent();

			txtFunction.Text = DefaultFormula;
		
			// FunctionSeries uses MindFusion.Scripting to evaluate
			// function expression and present its results as a Series
			lineChart.Series.Add(
				new FunctionSeries(DefaultFormula, 100000, 10000)
			);

			((FunctionSeries)lineChart.Series[0]).Title = "Series 1";

			// add a color for each series
			lineChart.Plot.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(192, 192, 192)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(125, 125, 125))
				},
				Strokes = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(192, 192, 192)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(125, 125, 125))
				}
			};

			lineChart.XAxis.Interval = 50;
			lineChart.XAxis.MinValue = 0;
			lineChart.XAxis.MaxValue = 500;
			lineChart.YAxis.MinValue = -100;
			lineChart.YAxis.MaxValue = 100;
			lineChart.ShowLegendTitle = false;


			lineChart.GridType = GridType.Crossed;
			lineChart.Theme.GridLineColor = Color.LightGray;
			lineChart.Theme.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash;
			lineChart.Plot.Background = new MindFusion.Drawing.SolidBrush(Color.White);
		}

		private void btnFunction_Click(object sender, EventArgs e)
		{
			try
			{
				lineChart.Series.Add(
					new FunctionSeries(txtFunction.Text, 100000, 100000));

				((FunctionSeries)lineChart.Series[lineChart.Series.Count - 1]).Title = "Series " + lineChart.Series.Count;
			}
			catch (Exception ex)
			{
				txtFunction.Text = ex.Message;
			}
		}

		private void btnClear_Click(object sender, EventArgs e)
		{
			lineChart.Series.Clear();
		}
	}
}